import tkinter as tk
from tkinter import filedialog
import subprocess
import threading
import os

def convert_moflex_to_mp4(input_folder, output_folder):
    try:
        if not os.path.exists(output_folder):
            os.makedirs(output_folder)

        for root, _, files in os.walk(input_folder):
            for file in files:
                if file.endswith(".moflex"):
                    input_file = os.path.join(root, file)
                    output_file = os.path.join(output_folder, os.path.splitext(file)[0] + ".mp4")

                    cmd = ['ffmpeg', '-i', input_file, '-c:v', 'libx264', '-preset', 'medium', '-crf', '23', '-c:a', 'aac', '-strict', 'experimental', '-b:a', '192k', output_file]
                    process = subprocess.Popen(cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE, text=True, bufsize=1, universal_newlines=True)

                    for line in process.stderr:
                        print(line, end='')

                    process.stdout.close()
                    process.wait()
        result_label.config(text="Conversion completed.")
    except Exception as e:
        result_label.config(text=f"Error: {str(e)}")

def select_input_folder():
    input_folder = filedialog.askdirectory(title="Select Folder with Moflex Files")
    input_folder_entry.delete(0, tk.END)
    input_folder_entry.insert(0, input_folder)

def select_output_folder():
    output_folder = filedialog.askdirectory(title="Select Output Folder for MP4 Files")
    output_folder_entry.delete(0, tk.END)
    output_folder_entry.insert(0, output_folder)

app = tk.Tk()
app.title("Moflex to MP4 Batch Converter")

input_folder_label = tk.Label(app, text="Select Folder with Moflex Files:")
input_folder_label.pack()
input_folder_entry = tk.Entry(app)
input_folder_entry.pack()
input_folder_button = tk.Button(app, text="Browse", command=select_input_folder)
input_folder_button.pack()

output_folder_label = tk.Label(app, text="Select Output Folder for MP4 Files:")
output_folder_label.pack()
output_folder_entry = tk.Entry(app)
output_folder_entry.pack()
output_folder_button = tk.Button(app, text="Browse", command=select_output_folder)
output_folder_button.pack()

convert_button = tk.Button(app, text="Convert to MP4", command=lambda: convert_moflex_to_mp4(input_folder_entry.get(), os.path.join(output_folder_entry.get(), 'output')))
convert_button.pack()

result_label = tk.Label(app, text="")
result_label.pack()

app.mainloop()
